@@ -6,7 +6,7 @@ from energinetml.backend import default_backend as backend
 from energinetml.settings import DEFAULT_LOCATION, COMMAND_NAME
 
 from .add_gitignore import add_gitignore_lines
-from .add_pipelines import add_pipeline_files
+# from .add_pipelines import add_pipeline_files
 
 
 # Constants  TODO Move to Project class?
@@ -55,7 +55,7 @@ def _parse_input_project_name(ctx, param, value):
     """
     if value is None:
         default = os.path.split(ctx.params['path'])[1] \
-            if 'path' in ctx.params \
+            if ctx.params.get('path') \
             else None
 
         value = click.prompt(
@@ -128,7 +128,10 @@ def _parse_input_workspace_name(ctx, param, value):
     )
 
     if not existing_workspaces:
-        click.echo('No AzureML Workspaces exists in this resource group')
+        click.echo((
+            'No AzureML Workspaces exists in this '
+            'resource group: %s'
+        ) % ctx.params['resource_group'])
         raise click.Abort()
 
     if value is None:
@@ -174,15 +177,25 @@ def _parse_input_workspace_name(ctx, param, value):
               default=DEFAULT_LOCATION,
               required=False, type=str,
               help='Azure location (default: %s)' % DEFAULT_LOCATION)
+@click.option('--pipelines/--no-pipelines', default=True,
+              help='Add a pipeline files to the project')
+@click.option('--gitignore/--no-gitignore', default=True,
+              help='Add a gitignore file to the project')
 @click.pass_context
 def init_project(ctx, path, name, subscription_id, resource_group,
-                 workspace_name, location):
+                 workspace_name, location, pipelines, gitignore):
     """
     Create a new, empty machine learning project.
     """
     if not os.path.isdir(path):
         os.makedirs(path)
 
+    workspace = backend.get_workspace(
+        subscription_id=subscription_id,
+        resource_group=resource_group,
+        name=workspace_name,
+    )
+
     project = Project.create(
         path=path,
         name=name,
@@ -190,6 +203,8 @@ def init_project(ctx, path, name, subscription_id, resource_group,
         resource_group=resource_group,
         workspace_name=workspace_name,
         location=location,
+        vnet_name=workspace.tags['vnet_name'],
+        subnet_name=workspace.tags['subnet_name'],
     )
 
     click.echo('-' * 79)
@@ -198,7 +213,24 @@ def init_project(ctx, path, name, subscription_id, resource_group,
                % COMMAND_NAME)
     click.echo('-' * 79)
 
-    if click.confirm('Would you like a .gitignore added to your project?', default=True):  # noqa: E501
+    # -- Pipelines -----------------------------------------------------------
+
+    # if pipelines is None:
+    #     pipelines = click.confirm(
+    #         'Would you like Azure DevOps Pipelines added to your project?',
+    #         default=True
+    #     )
+    #
+    # if pipelines:
+    #     ctx.invoke(add_pipeline_files, project=project)
+
+    # -- gigignore  ----------------------------------------------------------
+
+    if gitignore is None:
+        gitignore = click.confirm(
+            'Would you like a .gitignore added to your project?',
+            default=True,
+        )
+
+    if gitignore:
         ctx.invoke(add_gitignore_lines, project=project)
-    if click.confirm('Would you like Azure DevOps Pipelines added to your project?', default=True):  # noqa: E501
-        ctx.invoke(add_pipeline_files, project=project)
